==> csp_editor-0.0.1.tar.gz: csp_editor/lib/Event/CustomSecurityPolicyListener.php <==
<?php
/**
 * @copyright Copyright (c) 2021 Thomas Citharel <nextcloud@tcit.fr>
 *
 * @author Thomas Citharel <nextcloud@tcit.fr>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

namespace OCA\CSPEditor\Event;

use OCA\CSPEditor\Service\CustomSecurityPolicyBuilder;
use OCP\EventDispatcher\Event;
use OCP\EventDispatcher\IEventListener;
use OCP\Security\CSP\AddContentSecurityPolicyEvent;

class CustomSecurityPolicyListener implements IEventListener {

	/**
	 * @var CustomSecurityPolicyBuilder
	 */
	private $customSecurityPolicyBuilder;

	public function __construct(CustomSecurityPolicyBuilder $customSecurityPolicyBuilder) {
		$this->customSecurityPolicyBuilder = $customSecurityPolicyBuilder;
	}

	public function handle(Event $event): void {
		if (!$event instanceof AddContentSecurityPolicyEvent) {
			return;
		}

		$policy = $this->customSecurityPolicyBuilder->buildPolicy();

		$event->addPolicy($policy);
	}
}

==> csp_editor-1.1.0.tar.gz: csp_editor/lib/Event/CustomSecurityPolicyListener.php <==
<?php
/**
 * @copyright Copyright (c) 2021 Thomas Citharel <nextcloud@tcit.fr>
 *
 * @author Thomas Citharel <nextcloud@tcit.fr>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

namespace OCA\CSPEditor\Event;

use OCA\CSPEditor\Service\CustomSecurityPolicyBuilder;
use OCP\EventDispatcher\Event;
use OCP\EventDispatcher\IEventListener;
use OCP\Security\CSP\AddContentSecurityPolicyEvent;

class CustomSecurityPolicyListener implements IEventListener {
	private CustomSecurityPolicyBuilder $customSecurityPolicyBuilder;

	public function __construct(CustomSecurityPolicyBuilder $customSecurityPolicyBuilder) {
		$this->customSecurityPolicyBuilder = $customSecurityPolicyBuilder;
	}

	public function handle(Event $event): void {
		if (!$event instanceof AddContentSecurityPolicyEvent) {
			return;
		}

		$policy = $this->customSecurityPolicyBuilder->buildPolicy();

		$event->addPolicy($policy);
	}
}
